# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .folder import Folder

__all__ = ["DatasetListFoldersResponse"]

DatasetListFoldersResponse: TypeAlias = List[Folder]
