# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .file import File

__all__ = ["FileListResponse"]

FileListResponse: TypeAlias = List[File]
