# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from ...spec_version import SpecVersion

__all__ = ["VersionListResponse"]

VersionListResponse: TypeAlias = List[SpecVersion]
